Using a name that gives better context.
---
 src/backends/webdav/NeonCXX.cpp |   12 ++++++------
 src/backends/webdav/NeonCXX.h   |   16 ++++++++--------
 2 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/src/backends/webdav/NeonCXX.cpp b/src/backends/webdav/NeonCXX.cpp
index eacc907..f40832b 100644
--- a/src/backends/webdav/NeonCXX.cpp
+++ b/src/backends/webdav/NeonCXX.cpp
@@ -354,7 +354,7 @@ int Session::sslVerify(void *userdata, int failures, const 
ne_ssl_certificate *c
 unsigned int Session::options(const std::string &path)
 {
     unsigned int caps;
-    check(ne_options2(m_session, path.c_str(), &caps));
+    check_error(ne_options2(m_session, path.c_str(), &caps));
     return caps;
 }
 #endif // HAVE_LIBNEON_OPTIONS
@@ -394,7 +394,7 @@ void Session::propfindURI(const std::string &path, int 
depth,
                              StringPrintf("%d status: redirected to %s", code, 
location.c_str()),
                              code, location);
     } else {
-        if (!check(error, code)) {
+        if (!check_error(error, code)) {
             goto retry;
         }
     }
@@ -470,7 +470,7 @@ void Session::flush()
     }
 }
 
-bool Session::check(int error, int code, const ne_status *status, const string 
&location)
+bool Session::check_error(int error, int code, const ne_status *status, const 
string &location)
 {
     flush();
 
@@ -810,7 +810,7 @@ bool Request::run()
         error = ne_xml_dispatch_request(m_req, m_parser->get());
     }
 
-    return check(error);
+    return check_error(error);
 }
 
 int Request::addResultData(void *userdata, const char *buf, size_t len)
@@ -820,9 +820,9 @@ int Request::addResultData(void *userdata, const char *buf, 
size_t len)
     return 0;
 }
 
-bool Request::check(int error)
+bool Request::check_error(int error)
 {
-    return m_session.check(error, getStatus()->code, getStatus(), 
getResponseHeader("Location"));
+    return m_session.check_error(error, getStatus()->code, getStatus(), 
getResponseHeader("Location"));
 }
 
 }
diff --git a/src/backends/webdav/NeonCXX.h b/src/backends/webdav/NeonCXX.h
index f4b5407..6fde70c 100644
--- a/src/backends/webdav/NeonCXX.h
+++ b/src/backends/webdav/NeonCXX.h
@@ -277,7 +277,7 @@ class Session {
      *
      * call sequence is this:
      * - startOperation()
-     * - repeat until success or final failure: create request, run(), check()
+     * - repeat until success or final failure: create request, run(), 
check_error()
      *
      * @param operation    internal descriptor for debugging (for example, 
PROPFIND)
      * @param deadline     time at which the operation must be completed, 
otherwise it'll be considered failed;
@@ -287,7 +287,7 @@ class Session {
 
     /**
      * to be called after each operation which might have produced debugging 
output by neon;
      * automatically called by check()
      */
     void flush();
 
@@ -303,7 +303,7 @@ class Session {
      * @return true for success, false if retry needed (only if deadline not 
empty);
      *         errors reported via exceptions
      */ 
-    bool check(int error, int code = 0, const ne_status *status = NULL,
+    bool check_error(int error, int code = 0, const ne_status *status = NULL,
                const string &location = "");
 
     ne_session *getSession() const { return m_session; }
@@ -321,9 +321,9 @@ class Session {
     ne_session *m_session;
     URI m_uri;
     std::string m_proxyURL;
-    /** time when last successul request completed, maintained by check() */
+    /** time when last successul request completed, maintained by 
check_error() */
     Timespec m_lastRequestEnd;
-    /** number of times a request was sent, maintained by startOperation(), 
the credentials callback, and check() */
+    /** number of times a request was sent, maintained by startOperation(), 
the credentials callback, and check_error() */
     int m_attempt;
 
     /** ne_set_server_auth() callback */
@@ -485,10 +485,10 @@ class Request
 
     /**
      * Execute the request. May only be called once per request. Uses
      * Session::check() underneath to detect fatal errors and throw
      * exceptions.
      *
      * @return result of Session::check()
      */
     bool run();
 
@@ -514,7 +514,7 @@ class Request
     static int addResultData(void *userdata, const char *buf, size_t len);
 
     /** throw error if error code *or* current status indicates failure */
-    bool check(int error);
+    bool check_error(int error);
 };
 
 /** thrown for 301 HTTP status */
@@ -287,7 +287,7 @@ class Session {
      * to be called after each operation which might have produced debugging 
output by neon;
-     * automatically called by check()
+     * automatically called by check_error()
      */
     void flush();
@@ -485,10 +485,10 @@ class Request
     /**
      * Execute the request. May only be called once per request. Uses
-     * Session::check() underneath to detect fatal errors and throw
+     * Session::check_error() underneath to detect fatal errors and throw
      * exceptions.
      *
@@ -485,10 +485,10 @@ class Request
      * exceptions.
      *
-     * @return result of Session::check()
+     * @return result of Session::check_error()
      */
     bool run();
-- 
1.7.4.1

_______________________________________________
SyncEvolution mailing list
[email protected]
http://lists.syncevolution.org/listinfo/syncevolution

Reply via email to